//+------------------------------------------------------------------+
//|                                                        mpxlib.mqh |
//|                                      Copyright  2008, sptrading | 
//+------------------------------------------------------------------+
#import "mpxlib.ex4"

/**
 Purpose: session
*/
static int mpxeAsiaSession = 1;
static int mpxeEUSession = 2;
static int mpxeUSASession = 4;
static int mpxeAllSessions = 7;

/**
 Purpose: draw a single market profile
 Params: bars, tick, draw options
 Return: poc prices
*/
void mpxMarketProfile(double& pocsPrices[], double& mpxVolume[], double pricesLow[], double pricesHigh[], int beginBar, int bars, double onetick, int sessions, bool drawText = true, bool drawBox = true, bool drawPOC = true, bool drawVolume = true);

/**
 Purpose: draw multiple market profiles
 Params: days, datetime or file with datetime
 Return: poc prices of the newest profile
*/
void mpxMarketProfileByDay(double& pocsPrices[], double& mpxVolume[], double pricesLow[], double pricesHigh[], int days, double onetick, int sessions, bool drawText = true, bool drawBox = true, bool drawPOC = true, bool drawVolume = true);
void mpxMarketProfileByDate(double& pocsPrices[], double& mpxVolume[], double pricesLow[], double pricesHigh[], datetime dt[], double onetick, int sessions, bool drawText = true, bool drawBox = true, bool drawPOC = true, bool drawVolume = true);
void mpxMarketProfileByFile(double& pocsPrices[], double& mpxVolume[], double pricesLow[], double pricesHigh[], string filename, double onetick, int sessions, bool drawText = true, bool drawBox = true, bool drawPOC = true, bool drawVolume = true);


/**
 Purpose: draw a single market profile
 Params: bars, tick, draw options
 Return: poc prices
*/
void mpxSendMailAlert(double pocsPrices[], bool std1Breakout, bool unitBreakout);

/**
 Purpose: fill the price levels
 Params: begin bar, number of bars, tick value
 Return: prices updated
 Note: price is resized
*/
void mpxPrices(double& prices[], double pricesLow[], double pricesHigh[], int beginBar, int bars, double onetick, int sessions);

/**
 Purpose: fill the mpx datetime (string formatted)
 Params: prices, begin bar, number of bars (same as used in mpxPrices())
 Return: mpx datetime updated
 Note: mpx is resized
*/
void mpxDatetime(string mpxDt[], double& mpxVolume[], double prices[], double pricesLow[], double pricesHigh[], int beginBar, int bars, int sessions);

/**
 Purpose: fill a line datetime array from a string formatted datetime
 Params: mpxDt in datetime format
 Return: dt updated
 Note: dt is resized
*/
void mpxMarketDtStrToDatetime(datetime& dt[], string mpxDt);

/**
 Purpose: fill the mpx distribution in text mode
 Params: mpx in datetime format
 Return: mpxText updated
 Note: mpxText is resized
*/
string mpxMarketProfileTextLine(string mpx);
void mpxMarketProfileText(string& mpxText[], string& mpxDt[]);

/**
 Purpose: find POC and value area indexes
 Params: datetime
 Return: index
 Note: use these vars to access pocsIndex
*/
static int mpxePOC = 0;
static int mpxeStd1Down = 1;
static int mpxeStd1Up = 2;
static int mpxeStd2Down = 3;
static int mpxeStd2Up = 4;
static int mpxeUnitDown = 5;
static int mpxeUnitUp = 6;
static int mpxeExcessDown = 7;
static int mpxeExcessUp = 8;
static int mpxeNumbers = 9;
void mpxPocIndex(int& pocsIndex[], string mpxDt[]);

/**
 Purpose: find POC prices
 Params: prices, index
 Return: prices
 Note: resize pocPrices, use these vars to access pocPrices
*/
void mpxPocPrices(double& pocsPrices[], double prices[], int pocsIndex[]);

/**
 Purpose: read datetime from files
 Params: filename
 Return: datetime, true if success
 Note: resize dt
*/
bool mpxReadDatetime(datetime& dt[], string filename);

/**
 Purpose: bars shifts from datetime
 Params: datetime
 Return: shifts
 Note: resize shifts
*/
void mpxBarShiftsFromDatetime(int& shifts[], datetime dt[]);

/**
 Purpose: log prices to file
 Params: price, filename, bars
 Return: true if success
*/
bool mpxLogPocPrices(double pocsPrices[], string filename, int beginBar, int bars, int sessions = 7);
bool mpxMarketProfileLog(double pricesLow[], double pricesHigh[], string datetimeFilename, string pocFilename, int sessions = 7);

/**
 Purpose: human name from period
 Return: name (as M5 for 5 mins, D1 1 day...)
*/
string mpxNameFromPeriod();

/********************************************
 Purpose: drawing utilities
********************************************/

/**
 Purpose: draw mpx distribution in text mode
 Params: prices, etxt, begin bar, number of bars, tick size (same as used in mpxPrices())
 Return: none
*/
void mpxDrawText(double prices[], string mpxText[], int beginBar, int bars, double onetick, color col = White);
void mpxDrawBox(double prices[], string mpxText[], int beginBar, int bars, double onetick);

/**
 Purpose: draw POCS rices
 Params: POC prices, bars
 Return: none
*/
void mpxDrawPocs(double& pocsPrices[], int beginBar, int bars);

/**
 Purpose: erase all drawings
 Return: none
*/
void mpxDrawErase();

/********************************************
 Purpose: utilities
********************************************/

/**
 Purpose: format a string left justified
 Params: string to fotmat
 Return: string fotmatted
*/
string mpxFormatLeft(string text);

/**
 Purpose: find the appropriate mpx symbol at that time
 Params: time
 Return: mpx symbol
*/
string mpxSymbolTime(datetime dt);

/**
 Purpose: find the appropriate mpx color for that mpx code or at that time
 Params: mpx code or time
 Return: mpx color
*/
color mpxSymbolColorByCode(string text);
color mpxSymbolColorByTime(datetime dt);


